@@ -1,11 +1,14 @@
 use strict;
 use File::Temp qw/:seekable/;
 use Mojo::Util ();
+use File::Basename qw(basename);
 sub Mojo::Weixin::_get_media {
     my $self = shift;
-    my $media_id = shift; 
+    my $msg = shift;
     my $callback = shift;
     my $type = shift;
+
+    my $media_id = $msg->media_id; 
     my $api = 'https://wx.qq.com/cgi-bin/mmwebwx-bin/webwxgetmsgimg';
     my @query_string = (
         '' => '',
@@ -15,9 +18,8 @@ sub Mojo::Weixin::_get_media {
     push @query_string,(type => "slave") if $type;
     $self->http_get($self->gen_url($api,@query_string), {Referer=>'https' . $self->domain .'/'},sub{
         my ($data,$ua,$tx) = @_;
-        return if not defined $data;
-        unless(defined $data){
-            $self->warn("media下载失败: " . $tx->error->{message});
+        if(not defined $data){
+            $self->warn("media[ " . $msg->media_id . " ]下载失败");
             return;
         }
         my $mime = $tx->res->headers->content_type;
@@ -32,6 +34,9 @@ sub Mojo::Weixin::_get_media {
                     :                           ".dat"
         ; 
         return unless defined $type;
+        $msg->media_mime($mime);
+        $msg->media_ext(substr($type,1));
+        $msg->media_data($data);
         if(defined $self->media_dir and not -d $self->media_dir){
             $self->error("无效的 media_dir: " . $self->media_dir);
             return;
@@ -47,9 +52,13 @@ sub Mojo::Weixin::_get_media {
             binmode $tmp;
             print $tmp $data;
             close $tmp;
-            $callback->($tmp->filename,$data,) if ref $callback eq "CODE";
+            $msg->media_path($tmp->filename);
+            $msg->media_name(basename($msg->media_path));
+            $msg->media_mtime(time);
+            $msg->media_size(length($data));
+            $callback->($tmp->filename,$data,$msg) if ref $callback eq "CODE";
         };
-        $self->error("[ ". __PACKAGE__ . " ] $@") if $@;
+        $self->die("[ ". __PACKAGE__ . " ] $@") if $@;
     });
 }
 1;
